@@ -262,10 +262,8 @@ data_read_cb (void *handle, void *buffer, size_t size)
 
   g_return_val_if_fail (G_IS_INPUT_STREAM (input_stream), -1);
 
-  g_input_stream_read_all (input_stream, buffer, size,
-                           &bytes_read, NULL, &local_error);
-
-  if (local_error != NULL)
+  if (!g_input_stream_read_all (input_stream, buffer, size,
+                                &bytes_read, NULL, &local_error))
     {
       set_errno_from_gio_error (local_error);
       g_clear_error (&local_error);
@@ -287,7 +285,7 @@ data_write_cb (void *handle, const void *buffer, size_t size)
   if (g_output_stream_write_all (output_stream, buffer, size,
                                  &bytes_written, NULL, &local_error))
     {
-      g_output_stream_flush (output_stream, NULL, &local_error);
+      (void)g_output_stream_flush (output_stream, NULL, &local_error);
     }
 
   if (local_error != NULL)
@@ -439,3 +437,29 @@ ot_gpgme_new_ctx (const char *homedir,
 
   return g_steal_pointer (&context);
 }
+
+void
+ot_gpgme_kill_agent (const char *homedir)
+{
+  g_return_if_fail (homedir != NULL);
+
+  /* Run gpg-connect-agent killagent /bye */
+  g_autoptr(GError) local_error = NULL;
+  g_autoptr(GSubprocess) proc = g_subprocess_new(G_SUBPROCESS_FLAGS_STDOUT_SILENCE,
+                                                 &local_error,
+                                                 "gpg-connect-agent",
+                                                 "--homedir",
+                                                 homedir,
+                                                 "killagent",
+                                                 "/bye",
+                                                 NULL);
+  if (proc == NULL) {
+    g_debug ("Spawning gpg-connect-agent failed: %s", local_error->message);
+    return;
+  }
+  if (!g_subprocess_wait_check (proc, NULL, &local_error)) {
+    g_debug ("Killing GPG agent with gpg-connect-agent failed: %s",
+             local_error->message);
+    return;
+  }
+}
