@@ -34,13 +34,24 @@ else
 fi
 . ${test_srcdir}/libtest-core.sh
 
+# Array of expressions to execute when exiting. Each expression should
+# be a single string (quoting if necessary) that will be eval'd. To add
+# a command to run on exit, append to the libtest_exit_cmds array like
+# libtest_exit_cmds+=(expr).
+libtest_exit_cmds=()
+run_exit_cmds() {
+  for expr in "${libtest_exit_cmds[@]}"; do
+    eval "${expr}" || true
+  done
+}
+trap run_exit_cmds EXIT
+
 save_core() {
   if [ -e core ]; then
     cp core "$test_srcdir/core"
   fi
 }
-
-trap save_core EXIT;
+libtest_exit_cmds+=(save_core)
 
 test_tmpdir=$(pwd)
 
@@ -594,15 +605,58 @@ skip_without_experimental () {
 }
 
 has_gpgme () {
+    local ret
     ${CMD_PREFIX} ostree --version > version.txt
-    assert_file_has_content version.txt '- gpgme'
+    grep -q -e '- gpgme' version.txt
+    ret=$?
     rm -f version.txt
-    true
+    return ${ret}
+}
+
+skip_without_gpgme() {
+    if ! has_gpgme; then
+        skip "no gpg support compiled in"
+    fi
+}
+
+# Find an appropriate gpg program to use. We want one that has the
+# --generate-key, --quick-set-expire and --quick-add-key options. The
+# gpg program to use is returend.
+which_gpg () {
+    local gpg
+    local gpg_options
+    local needed_options=(
+        --generate-key
+        --quick-set-expire
+        --quick-add-key
+    )
+    local opt
+
+    # Prefer gpg2 in case gpg refers to gpg1
+    if which gpg2 &>/dev/null; then
+        gpg=gpg2
+    elif which gpg &>/dev/null; then
+        gpg=gpg
+    else
+        # Succeed but don't return anything.
+        return 0
+    fi
+
+    # Make sure all the needed options are available
+    gpg_options=$(${gpg} --dump-options) || return 0
+    for opt in ${needed_options[*]}; do
+      grep -q -x -e "${opt}" <<< "${gpg_options}" || return 0
+    done
+
+    # Found an appropriate gpg
+    echo ${gpg}
 }
 
 libtest_cleanup_gpg () {
-    gpg-connect-agent --homedir ${test_tmpdir}/gpghome killagent /bye || true
+    local gpg_homedir=${1:-${test_tmpdir}/gpghome}
+    gpg-connect-agent --homedir "${gpg_homedir}" killagent /bye || true
 }
+libtest_exit_cmds+=(libtest_cleanup_gpg)
 
 is_bare_user_only_repo () {
   grep -q 'mode=bare-user-only' $1/config
